﻿using System;

namespace ELTE.ChatRoom.Client.Model
{
    /// <summary>
    /// Chatszoba modell típusa.
    /// </summary>
    public interface IChatRoomModel
    {
        /// <summary>
        /// Kapcsolat állapotának lekérdezése.
        /// </summary>
        Boolean IsConnected { get; }

        /// <summary>
        /// Kapcsolatváltás eseménye.
        /// </summary>
        event EventHandler ConnectionChanged;

        /// <summary>
        /// Üzenetfogadás eseménye.
        /// </summary>
        event EventHandler<MessageEventArgs> MessageReceived;

        /// <summary>
        /// Felhasználólista fogadás eseménye.
        /// </summary>
        event EventHandler<UserListEventArgs> UserListReceived;

        /// <summary>
        /// Csatlakozás távoli végponthoz.
        /// </summary>
        /// <param name="ipAddress">A távoli gép IP címe.</param>
        /// <param name="port">A távoli gép portszáma.</param>
        void Connect(String ipAddress, Int32 port);

        /// <summary>
        /// Bejelentkezés.
        /// </summary>
        /// <param name="userName">Felhasználónév.</param>
        void Login(String userName);

        /// <summary>
        /// Kijelentkezés.
        /// </summary>
        void Logout();

        /// <summary>
        /// Üzenet küldése.
        /// </summary>
        /// <param name="message">Üzenet.</param>
        void SendMessage(String message);

        /// <summary>
        /// Üzenet küldése.
        /// </summary>
        /// <param name="userName">A felhasználó neve.</param>
        /// <param name="message">Üzenet.</param>
        void SendMessage(String userName, String message);

        /// <summary>
        /// Kapcsolat bontása.
        /// </summary>
        void Disconnect();
    }
}
