﻿using System;
using System.ComponentModel;

namespace ELTE.ChatRoom.Client.ViewModel
{
    /// <summary>
    /// Nézetmodell ősosztály típusa.
    /// </summary>
    public abstract class ViewModelBase : INotifyPropertyChanged
    {
        /// <summary>
        /// Tulajdonság ellenőrzés végrehajtása.
        /// </summary>
        protected Boolean ValidateProperty { get; private set; }

        /// <summary>
        /// Nézetmodell ősosztály példányosítása.
        /// </summary>
        /// <param name="validateProperty">Tulajdonság ellenőrzés végrehajtása.</param>
        protected ViewModelBase(Boolean validateProperty = false)
        {
            ValidateProperty = validateProperty;
        }

        /// <summary>
        /// Tulajdonság változásának eseménye.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Tulajdonság változása ellenőrzéssel.
        /// </summary>
        /// <param name="propertyName">Tulajdonság neve.</param>
        protected virtual void OnPropertyChanged(String propertyName)
        {
            if (ValidateProperty && TypeDescriptor.GetProperties(this)[propertyName] == null)
            {
                throw new Exception("Invalid property name: " + propertyName);
            }

            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }

}
