﻿using System;
using Newtonsoft.Json;

namespace ELTE.ChatRoom.Communication
{
    /// <summary>
    /// Üzenetkódok felsorolási típusa.
    /// </summary>
    public enum MessageCode { Login, Logout, Text, List }

    /// <summary>
    /// Üzenet típusa.
    /// </summary>
    public class Message
    {
        /// <summary>
        /// Kód lekérdezése, vagy beállítása.
        /// </summary>
        public MessageCode Code { get; set; }

        /// <summary>
        /// Forrás felhasználónév lekérdezése, vagy beállítása.
        /// </summary>
        public String SourceName { get; set; }

        /// <summary>
        /// Cél felhasználónév lekérdezése, vagy beállítása.
        /// </summary>
        public String DestinationName { get; set; }

        /// <summary>
        /// Szöveg lekérdezése, vagy beállítása.
        /// </summary>
        public String Text { get; set; }

        /// <summary>
        /// Üzenet JSON alapú szérializációja.
        /// </summary>
        /// <param name="message">Üzenet.</param>
        /// <returns>Az üzenet JSON formátumban.</returns>
        public static String Serialize(Message message)
        {
            if (message == null)
                return null;

            return JsonConvert.SerializeObject(message); // átalakítás JSON formátumra
        }

        /// <summary>
        /// Üzenet visszaállítása JSON-ból.
        /// </summary>
        /// <param name="message">Üzenet.</param>
        /// <returns>A visszaállított üzenet.</returns>
        public static Message Deserialize(String message)
        {
            if (message == null)
                return null;

            return JsonConvert.DeserializeObject<Message>(message); // átalakítás JSON formátumról
        }
    }
}
